@@ -1,6 +1,6 @@
 #turbESN
-from core import ESN
-from _modes import (_DTYPE, _DEVICE, _LOGGING_FORMAT)
+from .core import ESN
+from ._modes import (_DTYPE, _DEVICE, _LOGGING_FORMAT)
 
 #Backends
 import torch
