@@ -24,7 +24,7 @@ from scipy.stats import loguniform, uniform
 
 # Read hyperparameter.json
 import importlib.resources as pkg_resources
-with pkg_resources.path(info,'hyperparameters.json') as hp_dict_path:
+with pkg_resources.path(__package__,'hyperparameters.json') as hp_dict_path:
     with open(hp_dict_path,'r') as f:
         HP_dict = json.load(f)  
 ###########################################################################################################
